| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.CustomSearch.Types
Contents
- Service Configuration
- CSEListImgType
- PromotionImage
- Context
- CSEListSiteSearchFilter
- SearchQueries
- ResultPagemapAdditionalItem
- SearchURL
- SearchSpelling
- CSEListImgDominantColor
- ResultImage
- CSEListSafe
- ResultPagemap
- CSEListImgColorType
- Result
- ResultLabelsItem
- SearchSearchInformation
- CSEListFilter
- Query
- PromotionBodyLinesItem
- Promotion
- Search
- CSEListLr
- ContextFacetsItemItem
- CSEListSearchType
- CSEListImgSize
Description
- customSearchService :: ServiceConfig
- data CSEListImgType
- data PromotionImage
- promotionImage :: PromotionImage
- piHeight :: Lens' PromotionImage (Maybe Int32)
- piWidth :: Lens' PromotionImage (Maybe Int32)
- piSource :: Lens' PromotionImage (Maybe Text)
- data Context
- context :: Context
- cFacets :: Lens' Context [[ContextFacetsItemItem]]
- cTitle :: Lens' Context (Maybe Text)
- data CSEListSiteSearchFilter
- data SearchQueries
- searchQueries :: HashMap Text [Query] -> SearchQueries
- sqAddtional :: Lens' SearchQueries (HashMap Text [Query])
- data ResultPagemapAdditionalItem
- resultPagemapAdditionalItem :: HashMap Text JSONValue -> ResultPagemapAdditionalItem
- rpaiAddtional :: Lens' ResultPagemapAdditionalItem (HashMap Text JSONValue)
- data SearchURL
- searchURL :: SearchURL
- suType :: Lens' SearchURL Text
- suTemplate :: Lens' SearchURL Text
- data SearchSpelling
- searchSpelling :: SearchSpelling
- ssCorrectedQuery :: Lens' SearchSpelling (Maybe Text)
- ssHTMLCorrectedQuery :: Lens' SearchSpelling (Maybe Text)
- data CSEListImgDominantColor
- data ResultImage
- resultImage :: ResultImage
- riThumbnailLink :: Lens' ResultImage (Maybe Text)
- riHeight :: Lens' ResultImage (Maybe Int32)
- riByteSize :: Lens' ResultImage (Maybe Int32)
- riContextLink :: Lens' ResultImage (Maybe Text)
- riThumbnailHeight :: Lens' ResultImage (Maybe Int32)
- riWidth :: Lens' ResultImage (Maybe Int32)
- riThumbnailWidth :: Lens' ResultImage (Maybe Int32)
- data CSEListSafe
- data ResultPagemap
- resultPagemap :: HashMap Text [ResultPagemapAdditionalItem] -> ResultPagemap
- rpAddtional :: Lens' ResultPagemap (HashMap Text [ResultPagemapAdditionalItem])
- data CSEListImgColorType
- data Result
- result :: Result
- rMime :: Lens' Result (Maybe Text)
- rImage :: Lens' Result (Maybe ResultImage)
- rPagemap :: Lens' Result (Maybe ResultPagemap)
- rDisplayLink :: Lens' Result (Maybe Text)
- rFileFormat :: Lens' Result (Maybe Text)
- rSnippet :: Lens' Result (Maybe Text)
- rKind :: Lens' Result Text
- rLink :: Lens' Result (Maybe Text)
- rHTMLSnippet :: Lens' Result (Maybe Text)
- rHTMLFormattedURL :: Lens' Result (Maybe Text)
- rCacheId :: Lens' Result (Maybe Text)
- rFormattedURL :: Lens' Result (Maybe Text)
- rHTMLTitle :: Lens' Result (Maybe Text)
- rLabels :: Lens' Result [ResultLabelsItem]
- rTitle :: Lens' Result (Maybe Text)
- data ResultLabelsItem
- resultLabelsItem :: ResultLabelsItem
- rliName :: Lens' ResultLabelsItem (Maybe Text)
- rliDisplayName :: Lens' ResultLabelsItem (Maybe Text)
- rliLabelWithOp :: Lens' ResultLabelsItem (Maybe Text)
- data SearchSearchInformation
- searchSearchInformation :: SearchSearchInformation
- ssiSearchTime :: Lens' SearchSearchInformation (Maybe Double)
- ssiFormattedSearchTime :: Lens' SearchSearchInformation (Maybe Text)
- ssiTotalResults :: Lens' SearchSearchInformation (Maybe Int64)
- ssiFormattedTotalResults :: Lens' SearchSearchInformation (Maybe Text)
- data CSEListFilter
- data Query
- query :: Query
- qImgDominantColor :: Lens' Query (Maybe Text)
- qOutputEncoding :: Lens' Query (Maybe Text)
- qSiteSearchFilter :: Lens' Query (Maybe Text)
- qInputEncoding :: Lens' Query (Maybe Text)
- qOrTerms :: Lens' Query (Maybe Text)
- qSearchTerms :: Lens' Query (Maybe Text)
- qStartPage :: Lens' Query (Maybe Int32)
- qRights :: Lens' Query (Maybe Text)
- qCount :: Lens' Query (Maybe Int32)
- qExcludeTerms :: Lens' Query (Maybe Text)
- qFileType :: Lens' Query (Maybe Text)
- qSearchType :: Lens' Query (Maybe Text)
- qGoogleHost :: Lens' Query (Maybe Text)
- qDisableCnTwTranslation :: Lens' Query (Maybe Text)
- qRelatedSite :: Lens' Query (Maybe Text)
- qHl :: Lens' Query (Maybe Text)
- qCref :: Lens' Query (Maybe Text)
- qSort :: Lens' Query (Maybe Text)
- qLanguage :: Lens' Query (Maybe Text)
- qSiteSearch :: Lens' Query (Maybe Text)
- qFilter :: Lens' Query (Maybe Text)
- qTotalResults :: Lens' Query (Maybe Int64)
- qDateRestrict :: Lens' Query (Maybe Text)
- qTitle :: Lens' Query (Maybe Text)
- qLinkSite :: Lens' Query (Maybe Text)
- qLowRange :: Lens' Query (Maybe Text)
- qImgType :: Lens' Query (Maybe Text)
- qGl :: Lens' Query (Maybe Text)
- qCx :: Lens' Query (Maybe Text)
- qImgColorType :: Lens' Query (Maybe Text)
- qImgSize :: Lens' Query (Maybe Text)
- qExactTerms :: Lens' Query (Maybe Text)
- qStartIndex :: Lens' Query (Maybe Int32)
- qCr :: Lens' Query (Maybe Text)
- qSafe :: Lens' Query (Maybe Text)
- qHq :: Lens' Query (Maybe Text)
- qHighRange :: Lens' Query (Maybe Text)
- data PromotionBodyLinesItem
- promotionBodyLinesItem :: PromotionBodyLinesItem
- pbliLink :: Lens' PromotionBodyLinesItem (Maybe Text)
- pbliURL :: Lens' PromotionBodyLinesItem (Maybe Text)
- pbliHTMLTitle :: Lens' PromotionBodyLinesItem (Maybe Text)
- pbliTitle :: Lens' PromotionBodyLinesItem (Maybe Text)
- data Promotion
- promotion :: Promotion
- pImage :: Lens' Promotion (Maybe PromotionImage)
- pDisplayLink :: Lens' Promotion (Maybe Text)
- pBodyLines :: Lens' Promotion [PromotionBodyLinesItem]
- pLink :: Lens' Promotion (Maybe Text)
- pHTMLTitle :: Lens' Promotion (Maybe Text)
- pTitle :: Lens' Promotion (Maybe Text)
- data Search
- search :: Search
- sQueries :: Lens' Search (Maybe SearchQueries)
- sContext :: Lens' Search (Maybe Context)
- sKind :: Lens' Search Text
- sURL :: Lens' Search (Maybe SearchURL)
- sItems :: Lens' Search [Result]
- sSearchInformation :: Lens' Search (Maybe SearchSearchInformation)
- sPromotions :: Lens' Search [Promotion]
- sSpelling :: Lens' Search (Maybe SearchSpelling)
- data CSEListLr
- data ContextFacetsItemItem
- contextFacetsItemItem :: ContextFacetsItemItem
- cfiiAnchor :: Lens' ContextFacetsItemItem (Maybe Text)
- cfiiLabelWithOp :: Lens' ContextFacetsItemItem (Maybe Text)
- cfiiLabel :: Lens' ContextFacetsItemItem (Maybe Text)
- data CSEListSearchType = Image
- data CSEListImgSize
Service Configuration
customSearchService :: ServiceConfig Source #
Default request referring to version v1 of the CustomSearch API. This contains the host and root path used as a starting point for constructing service requests.
CSEListImgType
data CSEListImgType Source #
Returns images of a type, which can be one of: clipart, face, lineart, news, and photo.
Instances
PromotionImage
data PromotionImage Source #
promotionImage :: PromotionImage Source #
Creates a value of PromotionImage with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
Context
CSEListSiteSearchFilter
data CSEListSiteSearchFilter Source #
Controls whether to include or exclude results from the site named in the as_sitesearch parameter
Instances
SearchQueries
data SearchQueries Source #
Arguments
| :: HashMap Text [Query] | |
| -> SearchQueries |
Creates a value of SearchQueries with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
sqAddtional :: Lens' SearchQueries (HashMap Text [Query]) Source #
ResultPagemapAdditionalItem
data ResultPagemapAdditionalItem Source #
Instances
resultPagemapAdditionalItem Source #
Arguments
| :: HashMap Text JSONValue | |
| -> ResultPagemapAdditionalItem |
Creates a value of ResultPagemapAdditionalItem with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
SearchURL
searchURL :: SearchURL Source #
Creates a value of SearchURL with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
SearchSpelling
data SearchSpelling Source #
searchSpelling :: SearchSpelling Source #
Creates a value of SearchSpelling with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
CSEListImgDominantColor
data CSEListImgDominantColor Source #
Returns images of a specific dominant color: yellow, green, teal, blue, purple, pink, white, gray, black and brown.
Constructors
| Black |
|
| Blue |
|
| Brown |
|
| Gray |
|
| Green |
|
| Pink |
|
| Purple |
|
| Teal |
|
| White |
|
| Yellow |
|
Instances
ResultImage
data ResultImage Source #
Instances
resultImage :: ResultImage Source #
Creates a value of ResultImage with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
riByteSize :: Lens' ResultImage (Maybe Int32) Source #
CSEListSafe
data CSEListSafe Source #
Search safety level
Constructors
| High |
|
| Medium |
|
| Off |
|
Instances
ResultPagemap
data ResultPagemap Source #
Arguments
| :: HashMap Text [ResultPagemapAdditionalItem] | |
| -> ResultPagemap |
Creates a value of ResultPagemap with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
CSEListImgColorType
data CSEListImgColorType Source #
Returns black and white, grayscale, or color images: mono, gray, and color.
Constructors
| CSELICTColor |
|
| CSELICTGray |
|
| CSELICTMono |
|
Instances
Result
Creates a value of Result with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ResultLabelsItem
data ResultLabelsItem Source #
resultLabelsItem :: ResultLabelsItem Source #
Creates a value of ResultLabelsItem with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
SearchSearchInformation
searchSearchInformation :: SearchSearchInformation Source #
Creates a value of SearchSearchInformation with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
CSEListFilter
data CSEListFilter Source #
Controls turning on or off the duplicate content filter.
Instances
Query
Creates a value of Query with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
qImgDominantColorqOutputEncodingqSiteSearchFilterqInputEncodingqOrTermsqSearchTermsqStartPageqRightsqCountqExcludeTermsqFileTypeqSearchTypeqGoogleHostqDisableCnTwTranslationqRelatedSiteqHlqCrefqSortqLanguageqSiteSearchqFilterqTotalResultsqDateRestrictqTitleqLinkSiteqLowRangeqImgTypeqGlqCxqImgColorTypeqImgSizeqExactTermsqStartIndexqCrqSafeqHqqHighRange
PromotionBodyLinesItem
promotionBodyLinesItem :: PromotionBodyLinesItem Source #
Creates a value of PromotionBodyLinesItem with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
Promotion
promotion :: Promotion Source #
Creates a value of Promotion with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
Search
Creates a value of Search with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
CSEListLr
The language restriction for the search results
Constructors
| LangAr |
|
| LangBg |
|
| LangCa |
|
| LangCs |
|
| LangDa |
|
| LangDe |
|
| LangEl |
|
| LangEn |
|
| LangEs |
|
| LangEt |
|
| LangFi |
|
| LangFr |
|
| LangHr |
|
| LangHu |
|
| LangId |
|
| LangIs |
|
| LangIt |
|
| LangIw |
|
| LangJa |
|
| LangKo |
|
| LangLT |
|
| LangLv |
|
| LangNl |
|
| LangNo |
|
| LangPl |
|
| LangPt |
|
| LangRo |
|
| LangRu |
|
| LangSk |
|
| LangSl |
|
| LangSr |
|
| LangSv |
|
| LangTr |
|
| LangZhCn |
|
| LangZhTw |
|
Instances
ContextFacetsItemItem
data ContextFacetsItemItem Source #
contextFacetsItemItem :: ContextFacetsItemItem Source #
Creates a value of ContextFacetsItemItem with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
CSEListSearchType
data CSEListSearchType Source #
Specifies the search type: image.
Constructors
| Image |
|
Instances
CSEListImgSize
data CSEListImgSize Source #
Returns images of a specified size, where size can be one of: icon, small, medium, large, xlarge, xxlarge, and huge.
Constructors
| CSELISHuge |
|
| CSELISIcon |
|
| CSELISLarge |
|
| CSELISMedium |
|
| CSELISSmall |
|
| CSELISXlarge |
|
| CSELISXxlarge |
|
Instances